%define anolis_release 3 

Name:           fish
Version:        3.6.0
Release:        %{anolis_release}%{?dist}
Summary:        A smart and user-friendly command line shell
License:        GPLv2 and BSD and ISC and LGPLv2+ and MIT
URL:            https://fishshell.com
Source0:        https://github.com/fish-shell/fish-shell/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  cmake >= 3.5 gcc gcc-c++ ninja-build
BuildRequires:  python%{python3_pkgversion}-devel python%{python3_pkgversion}-pexpect
BuildRequires:  gettext gnupg2 procps-ng
BuildRequires:  ncurses-devel pcre2-devel
BuildRequires:  glibc-langpack-en
BuildRequires:  /usr/bin/sphinx-build
BuildRequires:  /usr/bin/desktop-file-validate

Patch: 0001-fix-cve-2023-51589.patch

Recommends:     man-db man-pages groff-base

Provides:       bundled(js-angular) = 1.8.2

%description
%{name} is a smart and user-friendly command line shell for macOS, Linux, and the
rest of the family. %{name} includes features like syntax highlighting,
autosuggest-as-you-type, and fancy tab completions that just work, with no
configuration required.

%package        doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

find share/tools -type f -name '*.py' -exec sed -i -e '1{s@^#!.*@#!%{__python3}@}' {} +
sed -i '/{TEST_GROUP("universal"), test_universal_notifiers}/d' src/%{name}_tests.cpp

%build
%cmake -GNinja \
  -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} \
  -DBUILD_DOCS=ON \
  -Dextra_confdir=%{_datadir}/%{name}/vendor_conf.d \
  -Dextra_completionsdir=%{_datadir}/%{name}/vendor_completions.d \
  -Dextra_functionsdir=%{_datadir}/%{name}/vendor_functions.d

%cmake_build -t all doc %{name}_tests

sed -i 's^/usr/local/^/usr/^g' %{_vpath_builddir}/*.pc

%install
%cmake_install

%py_byte_compile %{python3} %{buildroot}%{_datadir}/%{name}/tools/

cp -a CONTRIBUTING.rst README.rst CHANGELOG.rst %{buildroot}%{_pkgdocdir}

%find_lang %{name}

%generate_compatibility_deps

%check
%ninja_build -C %{_vpath_builddir} test
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop

%post
if [[ "$1" -eq 1 ]]; then
  shells_file="%{_sysconfdir}/shells"
  if ! grep -q "^%{_bindir}/%{name}$" "$shells_file" 2>/dev/null; then
    echo "%{_bindir}/%{name}" >> "$shells_file"
  fi
  if ! grep -q "^/bin/%{name}$" "$shells_file" 2>/dev/null; then
    echo "/bin/%{name}" >> "$shells_file"
  fi
fi

%postun
[ "$1" = 0 ] && [ -f %{_sysconfdir}/shells ] && sed -i "/^%{_bindir}/%{name}$\|^/bin/%{name}$/d" %{_sysconfdir}/shells

%files -f %{name}.lang
%dir %{abidir}
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}_indent
%{_bindir}/%{name}_key_reader
%{abidir}/%{name}_indent-option.list
%{abidir}/%{name}_key_reader-option.list
%config(noreplace) %{_sysconfdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/pkgconfig/%{name}.pc
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}*.1*

%files doc
%doc %{_pkgdocdir}

%changelog
* Tue Apr 22 2025 Ali <shenzhongli@inspur.com> - 3.6.0-3
- fix CVE-2023-51589

* Tue Apr 11 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 3.6.0-2
- Optimize the spec file

* Sun Apr 09 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 3.6.0-1
- Initial build for Anolis 23
